@@ -96,6 +96,11 @@ class Snapshot(Resource):
         """`dict` or `None` - The enStratus account where the snapshot is registered"""
         return self.__owning_account
 
+    @lazy_property
+    def owning_user(self):
+        """`dict` or `None` - The enStratus user who has ownership of this snapshot"""
+        return self.__owning_user
+
     @lazy_property
     def owning_groups(self):
         """`dict` - The enStratus groups who have ownership of this snapshot"""
